"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ISuperStreamSchema = void 0;
// Generated by ts-to-zod
const zod_1 = require("zod");
const ObjectMeta_schema_1 = require("@soft-stech/apimachinery/apis/meta/v1/ObjectMeta.schema");
/**
 * SuperStream is the Schema for the queues API
 */
exports.ISuperStreamSchema = zod_1.z.object({
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    "apiVersion": zod_1.z.literal("rabbitmq.com/v1alpha1"),
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    "kind": zod_1.z.literal("SuperStream"),
    "metadata": ObjectMeta_schema_1.iObjectMetaSchema.optional(),
    /**
     * SuperStreamSpec defines the desired state of SuperStream
     */
    "spec": zod_1.z.object({
        /**
         * Name of the queue; required property.
         */
        "name": zod_1.z.string(),
        /**
         * Number of partitions to create within this super stream. Defaults to '3'.
         * @default 3
         */
        "partitions": zod_1.z.number().optional().default(3),
        /**
         * Reference to the RabbitmqCluster that the SuperStream will be created in. Required property.
         */
        "rabbitmqClusterReference": zod_1.z.object({
            /**
             * Secret contains the http management uri for the RabbitMQ cluster. The Secret must contain the key `uri`, `username` and `password` or operator will error. Have to set either name or connectionSecret, but not both.
             */
            "connectionSecret": zod_1.z.object({
                /**
                 * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                 */
                "name": zod_1.z.string().optional()
            }).optional(),
            /**
             * The name of the RabbitMQ cluster to reference. Have to set either name or connectionSecret, but not both.
             */
            "name": zod_1.z.string().optional(),
            /**
             * The namespace of the RabbitMQ cluster to reference. Defaults to the namespace of the requested resource if omitted.
             */
            "namespace": zod_1.z.string().optional()
        }),
        /**
         * Routing keys to use for each of the partitions in the SuperStream If unset, the routing keys for the partitions will be set to the index of the partitions
         */
        "routingKeys": zod_1.z.array(zod_1.z.string()).optional(),
        /**
         * Default to vhost '/'; cannot be updated
         * @default "/"
         */
        "vhost": zod_1.z.string().optional().default("/")
    }).optional(),
    /**
     * SuperStreamStatus defines the observed state of SuperStream
     */
    "status": zod_1.z.object({
        "conditions": zod_1.z.array(zod_1.z.object({
            /**
             * The last time this Condition status changed.
             * @format date-time
             */
            "lastTransitionTime": zod_1.z.string().datetime().optional().nullable(),
            /**
             * Full text reason for current status of the condition.
             */
            "message": zod_1.z.string().optional(),
            /**
             * One word, camel-case reason for current status of the condition.
             */
            "reason": zod_1.z.string().optional(),
            /**
             * True, False, or Unknown
             */
            "status": zod_1.z.string(),
            /**
             * Type indicates the scope of the custom resource status addressed by the condition.
             */
            "type": zod_1.z.string()
        })).optional(),
        /**
         * observedGeneration is the most recent successful generation observed for this SuperStream. It corresponds to the SuperStream's generation, which is updated on mutation by the API Server.
         * @format int64
         */
        "observedGeneration": zod_1.z.number().optional(),
        /**
         * Partitions are a list of the stream queue names which form the partitions of this SuperStream.
         */
        "partitions": zod_1.z.array(zod_1.z.string()).optional()
    }).optional()
});
