import { addSchema } from "@soft-stech/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta";
import { Model, setSchema, createTypeMetaGuard } from "@soft-stech/base";
import { register } from "@soft-stech/validate";
const schemaId = "rabbitmq.com.v1beta1.Federation";
const schema = {
    "type": "object",
    "properties": {
        "apiVersion": {
            "type": "string",
            "enum": [
                "rabbitmq.com/v1beta1"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "Federation"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        },
        "spec": {
            "properties": {
                "ackMode": {
                    "enum": [
                        "on-confirm",
                        "on-publish",
                        "no-ack"
                    ],
                    "type": "string",
                    "nullable": true
                },
                "exchange": {
                    "type": "string",
                    "nullable": true
                },
                "expires": {
                    "type": "integer",
                    "nullable": true
                },
                "maxHops": {
                    "type": "integer",
                    "nullable": true
                },
                "messageTTL": {
                    "type": "integer",
                    "nullable": true
                },
                "name": {
                    "type": "string"
                },
                "prefetch-count": {
                    "type": "integer",
                    "nullable": true
                },
                "queue": {
                    "type": "string",
                    "nullable": true
                },
                "rabbitmqClusterReference": {
                    "properties": {
                        "connectionSecret": {
                            "properties": {
                                "name": {
                                    "type": "string",
                                    "nullable": true
                                }
                            },
                            "type": "object",
                            "nullable": true
                        },
                        "name": {
                            "type": "string",
                            "nullable": true
                        },
                        "namespace": {
                            "type": "string",
                            "nullable": true
                        }
                    },
                    "type": "object"
                },
                "reconnectDelay": {
                    "type": "integer",
                    "nullable": true
                },
                "trustUserId": {
                    "type": "boolean",
                    "nullable": true
                },
                "uriSecret": {
                    "properties": {
                        "name": {
                            "type": "string",
                            "nullable": true
                        }
                    },
                    "type": "object"
                },
                "vhost": {
                    "default": "/",
                    "type": "string",
                    "nullable": true
                }
            },
            "required": [
                "name",
                "rabbitmqClusterReference",
                "uriSecret"
            ],
            "type": "object",
            "nullable": true
        },
        "status": {
            "properties": {
                "conditions": {
                    "items": {
                        "properties": {
                            "lastTransitionTime": {
                                "format": "date-time",
                                "type": "string",
                                "nullable": true
                            },
                            "message": {
                                "type": "string",
                                "nullable": true
                            },
                            "reason": {
                                "type": "string",
                                "nullable": true
                            },
                            "status": {
                                "type": "string"
                            },
                            "type": {
                                "type": "string"
                            }
                        },
                        "required": [
                            "status",
                            "type"
                        ],
                        "type": "object"
                    },
                    "type": "array",
                    "nullable": true
                },
                "observedGeneration": {
                    "format": "int64",
                    "type": "integer",
                    "nullable": true
                }
            },
            "type": "object",
            "nullable": true
        }
    },
    "required": [
        "apiVersion",
        "kind"
    ]
};
/**
 * Federation is the Schema for the federations API
 */
export class Federation extends Model {
    constructor(data) {
        super({
            apiVersion: Federation.apiVersion,
            kind: Federation.kind,
            ...data
        });
    }
}
Federation.apiVersion = "rabbitmq.com/v1beta1";
Federation.kind = "Federation";
Federation.is = createTypeMetaGuard(Federation);
setSchema(Federation, schemaId, () => {
    addSchema();
    register(schemaId, schema);
});
