import { addSchema } from "@soft-stech/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta";
import { Model, setSchema, createTypeMetaGuard } from "@soft-stech/base";
import { register } from "@soft-stech/validate";
const schemaId = "rabbitmq.com.v1beta1.Permission";
const schema = {
    "type": "object",
    "properties": {
        "apiVersion": {
            "type": "string",
            "enum": [
                "rabbitmq.com/v1beta1"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "Permission"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        },
        "spec": {
            "properties": {
                "permissions": {
                    "properties": {
                        "configure": {
                            "type": "string",
                            "nullable": true
                        },
                        "read": {
                            "type": "string",
                            "nullable": true
                        },
                        "write": {
                            "type": "string",
                            "nullable": true
                        }
                    },
                    "type": "object"
                },
                "rabbitmqClusterReference": {
                    "properties": {
                        "connectionSecret": {
                            "properties": {
                                "name": {
                                    "type": "string",
                                    "nullable": true
                                }
                            },
                            "type": "object",
                            "nullable": true
                        },
                        "name": {
                            "type": "string",
                            "nullable": true
                        },
                        "namespace": {
                            "type": "string",
                            "nullable": true
                        }
                    },
                    "type": "object"
                },
                "user": {
                    "type": "string",
                    "nullable": true
                },
                "userReference": {
                    "properties": {
                        "name": {
                            "type": "string",
                            "nullable": true
                        }
                    },
                    "type": "object",
                    "nullable": true
                },
                "vhost": {
                    "type": "string"
                }
            },
            "required": [
                "permissions",
                "rabbitmqClusterReference",
                "vhost"
            ],
            "type": "object",
            "nullable": true
        },
        "status": {
            "properties": {
                "conditions": {
                    "items": {
                        "properties": {
                            "lastTransitionTime": {
                                "format": "date-time",
                                "type": "string",
                                "nullable": true
                            },
                            "message": {
                                "type": "string",
                                "nullable": true
                            },
                            "reason": {
                                "type": "string",
                                "nullable": true
                            },
                            "status": {
                                "type": "string"
                            },
                            "type": {
                                "type": "string"
                            }
                        },
                        "required": [
                            "status",
                            "type"
                        ],
                        "type": "object"
                    },
                    "type": "array",
                    "nullable": true
                },
                "observedGeneration": {
                    "format": "int64",
                    "type": "integer",
                    "nullable": true
                }
            },
            "type": "object",
            "nullable": true
        }
    },
    "required": [
        "apiVersion",
        "kind"
    ]
};
/**
 * Permission is the Schema for the permissions API
 */
export class Permission extends Model {
    constructor(data) {
        super({
            apiVersion: Permission.apiVersion,
            kind: Permission.kind,
            ...data
        });
    }
}
Permission.apiVersion = "rabbitmq.com/v1beta1";
Permission.kind = "Permission";
Permission.is = createTypeMetaGuard(Permission);
setSchema(Permission, schemaId, () => {
    addSchema();
    register(schemaId, schema);
});
