import { addSchema } from "@soft-stech/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta";
import { Model, setSchema, createTypeMetaGuard } from "@soft-stech/base";
import { register } from "@soft-stech/validate";
const schemaId = "rabbitmq.com.v1beta1.Policy";
const schema = {
    "type": "object",
    "properties": {
        "apiVersion": {
            "type": "string",
            "enum": [
                "rabbitmq.com/v1beta1"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "Policy"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        },
        "spec": {
            "properties": {
                "applyTo": {
                    "default": "all",
                    "enum": [
                        "queues",
                        "exchanges",
                        "all"
                    ],
                    "type": "string",
                    "nullable": true
                },
                "definition": {
                    "type": "object",
                    "properties": {}
                },
                "name": {
                    "type": "string"
                },
                "pattern": {
                    "type": "string"
                },
                "priority": {
                    "default": 0,
                    "type": "integer",
                    "nullable": true
                },
                "rabbitmqClusterReference": {
                    "properties": {
                        "connectionSecret": {
                            "properties": {
                                "name": {
                                    "type": "string",
                                    "nullable": true
                                }
                            },
                            "type": "object",
                            "nullable": true
                        },
                        "name": {
                            "type": "string",
                            "nullable": true
                        },
                        "namespace": {
                            "type": "string",
                            "nullable": true
                        }
                    },
                    "type": "object"
                },
                "vhost": {
                    "default": "/",
                    "type": "string",
                    "nullable": true
                }
            },
            "required": [
                "definition",
                "name",
                "pattern",
                "rabbitmqClusterReference"
            ],
            "type": "object",
            "nullable": true
        },
        "status": {
            "properties": {
                "conditions": {
                    "items": {
                        "properties": {
                            "lastTransitionTime": {
                                "format": "date-time",
                                "type": "string",
                                "nullable": true
                            },
                            "message": {
                                "type": "string",
                                "nullable": true
                            },
                            "reason": {
                                "type": "string",
                                "nullable": true
                            },
                            "status": {
                                "type": "string"
                            },
                            "type": {
                                "type": "string"
                            }
                        },
                        "required": [
                            "status",
                            "type"
                        ],
                        "type": "object"
                    },
                    "type": "array",
                    "nullable": true
                },
                "observedGeneration": {
                    "format": "int64",
                    "type": "integer",
                    "nullable": true
                }
            },
            "type": "object",
            "nullable": true
        }
    },
    "required": [
        "apiVersion",
        "kind"
    ]
};
/**
 * Policy is the Schema for the policies API
 */
export class Policy extends Model {
    constructor(data) {
        super({
            apiVersion: Policy.apiVersion,
            kind: Policy.kind,
            ...data
        });
    }
}
Policy.apiVersion = "rabbitmq.com/v1beta1";
Policy.kind = "Policy";
Policy.is = createTypeMetaGuard(Policy);
setSchema(Policy, schemaId, () => {
    addSchema();
    register(schemaId, schema);
});
