import { z } from "zod";
/**
 * Policy is the Schema for the policies API
 */
export declare const IPolicySchema: z.ZodObject<{
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    apiVersion: z.ZodLiteral<"rabbitmq.com/v1beta1">;
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    kind: z.ZodLiteral<"Policy">;
    metadata: z.ZodOptional<z.ZodObject<{
        annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        creationTimestamp: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        deletionGracePeriodSeconds: z.ZodOptional<z.ZodNumber>;
        deletionTimestamp: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        finalizers: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        generateName: z.ZodOptional<z.ZodString>;
        generation: z.ZodOptional<z.ZodNumber>;
        labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        managedFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
            apiVersion: z.ZodOptional<z.ZodString>;
            fieldsType: z.ZodOptional<z.ZodString>;
            fieldsV1: z.ZodOptional<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
            manager: z.ZodOptional<z.ZodString>;
            operation: z.ZodOptional<z.ZodString>;
            subresource: z.ZodOptional<z.ZodString>;
            time: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }, {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }>, "many">>;
        name: z.ZodOptional<z.ZodString>;
        namespace: z.ZodOptional<z.ZodString>;
        ownerReferences: z.ZodOptional<z.ZodArray<z.ZodObject<{
            apiVersion: z.ZodString;
            blockOwnerDeletion: z.ZodOptional<z.ZodBoolean>;
            controller: z.ZodOptional<z.ZodBoolean>;
            kind: z.ZodString;
            name: z.ZodString;
            uid: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }, {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }>, "many">>;
        resourceVersion: z.ZodOptional<z.ZodString>;
        selfLink: z.ZodOptional<z.ZodString>;
        uid: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    }, {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    }>>;
    /**
     * PolicySpec defines the desired state of Policy https://www.rabbitmq.com/parameters.html#policies
     */
    spec: z.ZodOptional<z.ZodObject<{
        /**
         * What this policy applies to: 'queues', 'exchanges', or 'all'. Default to 'all'.
         * @default "all"
         */
        applyTo: z.ZodDefault<z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"queues">, z.ZodLiteral<"exchanges">, z.ZodLiteral<"all">]>>>;
        /**
         * Policy definition. Required property.
         */
        definition: z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>;
        /**
         * Required property; cannot be updated
         */
        name: z.ZodString;
        /**
         * Regular expression pattern used to match queues and exchanges, e.g. "^amq.". Required property.
         */
        pattern: z.ZodString;
        /**
         * Default to '0'. In the event that more than one policy can match a given exchange or queue, the policy with the greatest priority applies.
         */
        priority: z.ZodOptional<z.ZodNumber>;
        /**
         * Reference to the RabbitmqCluster that the exchange will be created in. Required property.
         */
        rabbitmqClusterReference: z.ZodObject<{
            /**
             * Secret contains the http management uri for the RabbitMQ cluster. The Secret must contain the key `uri`, `username` and `password` or operator will error. Have to set either name or connectionSecret, but not both.
             */
            connectionSecret: z.ZodOptional<z.ZodObject<{
                /**
                 * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                 */
                name: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                name?: string | undefined;
            }, {
                name?: string | undefined;
            }>>;
            /**
             * The name of the RabbitMQ cluster to reference. Have to set either name or connectionSecret, but not both.
             */
            name: z.ZodOptional<z.ZodString>;
            /**
             * The namespace of the RabbitMQ cluster to reference. Defaults to the namespace of the requested resource if omitted.
             */
            namespace: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            name?: string | undefined;
            connectionSecret?: {
                name?: string | undefined;
            } | undefined;
            namespace?: string | undefined;
        }, {
            name?: string | undefined;
            connectionSecret?: {
                name?: string | undefined;
            } | undefined;
            namespace?: string | undefined;
        }>;
        /**
         * Default to vhost '/'; cannot be updated
         * @default "/"
         */
        vhost: z.ZodDefault<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        rabbitmqClusterReference: {
            name?: string | undefined;
            connectionSecret?: {
                name?: string | undefined;
            } | undefined;
            namespace?: string | undefined;
        };
        name: string;
        vhost: string;
        definition: {};
        pattern: string;
        applyTo: "all" | "queues" | "exchanges";
        priority?: number | undefined;
    }, {
        rabbitmqClusterReference: {
            name?: string | undefined;
            connectionSecret?: {
                name?: string | undefined;
            } | undefined;
            namespace?: string | undefined;
        };
        name: string;
        definition: {};
        pattern: string;
        vhost?: string | undefined;
        applyTo?: "all" | "queues" | "exchanges" | undefined;
        priority?: number | undefined;
    }>>;
    /**
     * PolicyStatus defines the observed state of Policy
     */
    status: z.ZodOptional<z.ZodObject<{
        conditions: z.ZodOptional<z.ZodArray<z.ZodObject<{
            /**
             * The last time this Condition status changed.
             * @format date-time
             */
            lastTransitionTime: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            /**
             * Full text reason for current status of the condition.
             */
            message: z.ZodOptional<z.ZodString>;
            /**
             * One word, camel-case reason for current status of the condition.
             */
            reason: z.ZodOptional<z.ZodString>;
            /**
             * True, False, or Unknown
             */
            status: z.ZodString;
            /**
             * Type indicates the scope of the custom resource status addressed by the condition.
             */
            type: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: string;
            status: string;
            message?: string | undefined;
            lastTransitionTime?: string | null | undefined;
            reason?: string | undefined;
        }, {
            type: string;
            status: string;
            message?: string | undefined;
            lastTransitionTime?: string | null | undefined;
            reason?: string | undefined;
        }>, "many">>;
        /**
         * observedGeneration is the most recent successful generation observed for this Policy. It corresponds to the Policy's generation, which is updated on mutation by the API Server.
         * @format int64
         */
        observedGeneration: z.ZodOptional<z.ZodNumber>;
    }, "strip", z.ZodTypeAny, {
        conditions?: {
            type: string;
            status: string;
            message?: string | undefined;
            lastTransitionTime?: string | null | undefined;
            reason?: string | undefined;
        }[] | undefined;
        observedGeneration?: number | undefined;
    }, {
        conditions?: {
            type: string;
            status: string;
            message?: string | undefined;
            lastTransitionTime?: string | null | undefined;
            reason?: string | undefined;
        }[] | undefined;
        observedGeneration?: number | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    apiVersion: "rabbitmq.com/v1beta1";
    kind: "Policy";
    status?: {
        conditions?: {
            type: string;
            status: string;
            message?: string | undefined;
            lastTransitionTime?: string | null | undefined;
            reason?: string | undefined;
        }[] | undefined;
        observedGeneration?: number | undefined;
    } | undefined;
    metadata?: {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    } | undefined;
    spec?: {
        rabbitmqClusterReference: {
            name?: string | undefined;
            connectionSecret?: {
                name?: string | undefined;
            } | undefined;
            namespace?: string | undefined;
        };
        name: string;
        vhost: string;
        definition: {};
        pattern: string;
        applyTo: "all" | "queues" | "exchanges";
        priority?: number | undefined;
    } | undefined;
}, {
    apiVersion: "rabbitmq.com/v1beta1";
    kind: "Policy";
    status?: {
        conditions?: {
            type: string;
            status: string;
            message?: string | undefined;
            lastTransitionTime?: string | null | undefined;
            reason?: string | undefined;
        }[] | undefined;
        observedGeneration?: number | undefined;
    } | undefined;
    metadata?: {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    } | undefined;
    spec?: {
        rabbitmqClusterReference: {
            name?: string | undefined;
            connectionSecret?: {
                name?: string | undefined;
            } | undefined;
            namespace?: string | undefined;
        };
        name: string;
        definition: {};
        pattern: string;
        vhost?: string | undefined;
        applyTo?: "all" | "queues" | "exchanges" | undefined;
        priority?: number | undefined;
    } | undefined;
}>;
