"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IPolicySchema = void 0;
// Generated by ts-to-zod
const zod_1 = require("zod");
const ObjectMeta_schema_1 = require("@soft-stech/apimachinery/apis/meta/v1/ObjectMeta.schema");
/**
 * Policy is the Schema for the policies API
 */
exports.IPolicySchema = zod_1.z.object({
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    "apiVersion": zod_1.z.literal("rabbitmq.com/v1beta1"),
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    "kind": zod_1.z.literal("Policy"),
    "metadata": ObjectMeta_schema_1.iObjectMetaSchema.optional(),
    /**
     * PolicySpec defines the desired state of Policy https://www.rabbitmq.com/parameters.html#policies
     */
    "spec": zod_1.z.object({
        /**
         * What this policy applies to: 'queues', 'exchanges', or 'all'. Default to 'all'.
         * @default "all"
         */
        "applyTo": zod_1.z.union([zod_1.z.literal("queues"), zod_1.z.literal("exchanges"), zod_1.z.literal("all")]).optional().default("all"),
        /**
         * Policy definition. Required property.
         */
        "definition": zod_1.z.object({}),
        /**
         * Required property; cannot be updated
         */
        "name": zod_1.z.string(),
        /**
         * Regular expression pattern used to match queues and exchanges, e.g. "^amq.". Required property.
         */
        "pattern": zod_1.z.string(),
        /**
         * Default to '0'. In the event that more than one policy can match a given exchange or queue, the policy with the greatest priority applies.
         */
        "priority": zod_1.z.number().optional(),
        /**
         * Reference to the RabbitmqCluster that the exchange will be created in. Required property.
         */
        "rabbitmqClusterReference": zod_1.z.object({
            /**
             * Secret contains the http management uri for the RabbitMQ cluster. The Secret must contain the key `uri`, `username` and `password` or operator will error. Have to set either name or connectionSecret, but not both.
             */
            "connectionSecret": zod_1.z.object({
                /**
                 * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                 */
                "name": zod_1.z.string().optional()
            }).optional(),
            /**
             * The name of the RabbitMQ cluster to reference. Have to set either name or connectionSecret, but not both.
             */
            "name": zod_1.z.string().optional(),
            /**
             * The namespace of the RabbitMQ cluster to reference. Defaults to the namespace of the requested resource if omitted.
             */
            "namespace": zod_1.z.string().optional()
        }),
        /**
         * Default to vhost '/'; cannot be updated
         * @default "/"
         */
        "vhost": zod_1.z.string().optional().default("/")
    }).optional(),
    /**
     * PolicyStatus defines the observed state of Policy
     */
    "status": zod_1.z.object({
        "conditions": zod_1.z.array(zod_1.z.object({
            /**
             * The last time this Condition status changed.
             * @format date-time
             */
            "lastTransitionTime": zod_1.z.string().datetime().optional().nullable(),
            /**
             * Full text reason for current status of the condition.
             */
            "message": zod_1.z.string().optional(),
            /**
             * One word, camel-case reason for current status of the condition.
             */
            "reason": zod_1.z.string().optional(),
            /**
             * True, False, or Unknown
             */
            "status": zod_1.z.string(),
            /**
             * Type indicates the scope of the custom resource status addressed by the condition.
             */
            "type": zod_1.z.string()
        })).optional(),
        /**
         * observedGeneration is the most recent successful generation observed for this Policy. It corresponds to the Policy's generation, which is updated on mutation by the API Server.
         * @format int64
         */
        "observedGeneration": zod_1.z.number().optional()
    }).optional()
});
