import { addSchema } from "@soft-stech/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta";
import { Model, setSchema, createTypeMetaGuard } from "@soft-stech/base";
import { register } from "@soft-stech/validate";
const schemaId = "rabbitmq.com.v1beta1.SchemaReplication";
const schema = {
    "type": "object",
    "properties": {
        "apiVersion": {
            "type": "string",
            "enum": [
                "rabbitmq.com/v1beta1"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "SchemaReplication"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        },
        "spec": {
            "properties": {
                "endpoints": {
                    "type": "string",
                    "nullable": true
                },
                "rabbitmqClusterReference": {
                    "properties": {
                        "connectionSecret": {
                            "properties": {
                                "name": {
                                    "type": "string",
                                    "nullable": true
                                }
                            },
                            "type": "object",
                            "nullable": true
                        },
                        "name": {
                            "type": "string",
                            "nullable": true
                        },
                        "namespace": {
                            "type": "string",
                            "nullable": true
                        }
                    },
                    "type": "object"
                },
                "secretBackend": {
                    "properties": {
                        "vault": {
                            "properties": {
                                "secretPath": {
                                    "type": "string",
                                    "nullable": true
                                }
                            },
                            "type": "object",
                            "nullable": true
                        }
                    },
                    "type": "object",
                    "nullable": true
                },
                "upstreamSecret": {
                    "properties": {
                        "name": {
                            "type": "string",
                            "nullable": true
                        }
                    },
                    "type": "object",
                    "nullable": true
                }
            },
            "required": [
                "rabbitmqClusterReference"
            ],
            "type": "object",
            "nullable": true
        },
        "status": {
            "properties": {
                "conditions": {
                    "items": {
                        "properties": {
                            "lastTransitionTime": {
                                "format": "date-time",
                                "type": "string",
                                "nullable": true
                            },
                            "message": {
                                "type": "string",
                                "nullable": true
                            },
                            "reason": {
                                "type": "string",
                                "nullable": true
                            },
                            "status": {
                                "type": "string"
                            },
                            "type": {
                                "type": "string"
                            }
                        },
                        "required": [
                            "status",
                            "type"
                        ],
                        "type": "object"
                    },
                    "type": "array",
                    "nullable": true
                },
                "observedGeneration": {
                    "format": "int64",
                    "type": "integer",
                    "nullable": true
                }
            },
            "type": "object",
            "nullable": true
        }
    },
    "required": [
        "apiVersion",
        "kind"
    ]
};
/**
 * SchemaReplication is the Schema for the schemareplications API This feature requires Tanzu RabbitMQ with schema replication plugin. For more information, see: https://tanzu.vmware.com/rabbitmq and https://www.rabbitmq.com/definitions-standby.html.
 */
export class SchemaReplication extends Model {
    constructor(data) {
        super({
            apiVersion: SchemaReplication.apiVersion,
            kind: SchemaReplication.kind,
            ...data
        });
    }
}
SchemaReplication.apiVersion = "rabbitmq.com/v1beta1";
SchemaReplication.kind = "SchemaReplication";
SchemaReplication.is = createTypeMetaGuard(SchemaReplication);
setSchema(SchemaReplication, schemaId, () => {
    addSchema();
    register(schemaId, schema);
});
