import { addSchema } from "@soft-stech/apimachinery/_schemas/IoK8sApimachineryPkgApisMetaV1ObjectMeta";
import { Model, setSchema, createTypeMetaGuard } from "@soft-stech/base";
import { register } from "@soft-stech/validate";
const schemaId = "rabbitmq.com.v1beta1.Shovel";
const schema = {
    "type": "object",
    "properties": {
        "apiVersion": {
            "type": "string",
            "enum": [
                "rabbitmq.com/v1beta1"
            ]
        },
        "kind": {
            "type": "string",
            "enum": [
                "Shovel"
            ]
        },
        "metadata": {
            "oneOf": [
                {
                    "$ref": "io.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta#"
                },
                {
                    "type": "null"
                }
            ]
        },
        "spec": {
            "properties": {
                "ackMode": {
                    "enum": [
                        "on-confirm",
                        "on-publish",
                        "no-ack"
                    ],
                    "type": "string",
                    "nullable": true
                },
                "addForwardHeaders": {
                    "type": "boolean",
                    "nullable": true
                },
                "deleteAfter": {
                    "type": "string",
                    "nullable": true
                },
                "destAddForwardHeaders": {
                    "type": "boolean",
                    "nullable": true
                },
                "destAddTimestampHeader": {
                    "type": "boolean",
                    "nullable": true
                },
                "destAddress": {
                    "type": "string",
                    "nullable": true
                },
                "destApplicationProperties": {
                    "type": "string",
                    "nullable": true
                },
                "destExchange": {
                    "type": "string",
                    "nullable": true
                },
                "destExchangeKey": {
                    "type": "string",
                    "nullable": true
                },
                "destProperties": {
                    "type": "string",
                    "nullable": true
                },
                "destProtocol": {
                    "type": "string",
                    "nullable": true
                },
                "destPublishProperties": {
                    "type": "string",
                    "nullable": true
                },
                "destQueue": {
                    "type": "string",
                    "nullable": true
                },
                "name": {
                    "type": "string"
                },
                "prefetchCount": {
                    "type": "integer",
                    "nullable": true
                },
                "rabbitmqClusterReference": {
                    "properties": {
                        "connectionSecret": {
                            "properties": {
                                "name": {
                                    "type": "string",
                                    "nullable": true
                                }
                            },
                            "type": "object",
                            "nullable": true
                        },
                        "name": {
                            "type": "string",
                            "nullable": true
                        },
                        "namespace": {
                            "type": "string",
                            "nullable": true
                        }
                    },
                    "type": "object"
                },
                "reconnectDelay": {
                    "type": "integer",
                    "nullable": true
                },
                "srcAddress": {
                    "type": "string",
                    "nullable": true
                },
                "srcDeleteAfter": {
                    "type": "string",
                    "nullable": true
                },
                "srcExchange": {
                    "type": "string",
                    "nullable": true
                },
                "srcExchangeKey": {
                    "type": "string",
                    "nullable": true
                },
                "srcPrefetchCount": {
                    "type": "integer",
                    "nullable": true
                },
                "srcProtocol": {
                    "type": "string",
                    "nullable": true
                },
                "srcQueue": {
                    "type": "string",
                    "nullable": true
                },
                "uriSecret": {
                    "properties": {
                        "name": {
                            "type": "string",
                            "nullable": true
                        }
                    },
                    "type": "object"
                },
                "vhost": {
                    "default": "/",
                    "type": "string",
                    "nullable": true
                }
            },
            "required": [
                "name",
                "rabbitmqClusterReference",
                "uriSecret"
            ],
            "type": "object",
            "nullable": true
        },
        "status": {
            "properties": {
                "conditions": {
                    "items": {
                        "properties": {
                            "lastTransitionTime": {
                                "format": "date-time",
                                "type": "string",
                                "nullable": true
                            },
                            "message": {
                                "type": "string",
                                "nullable": true
                            },
                            "reason": {
                                "type": "string",
                                "nullable": true
                            },
                            "status": {
                                "type": "string"
                            },
                            "type": {
                                "type": "string"
                            }
                        },
                        "required": [
                            "status",
                            "type"
                        ],
                        "type": "object"
                    },
                    "type": "array",
                    "nullable": true
                },
                "observedGeneration": {
                    "format": "int64",
                    "type": "integer",
                    "nullable": true
                }
            },
            "type": "object",
            "nullable": true
        }
    },
    "required": [
        "apiVersion",
        "kind"
    ]
};
/**
 * Shovel is the Schema for the shovels API
 */
export class Shovel extends Model {
    constructor(data) {
        super({
            apiVersion: Shovel.apiVersion,
            kind: Shovel.kind,
            ...data
        });
    }
}
Shovel.apiVersion = "rabbitmq.com/v1beta1";
Shovel.kind = "Shovel";
Shovel.is = createTypeMetaGuard(Shovel);
setSchema(Shovel, schemaId, () => {
    addSchema();
    register(schemaId, schema);
});
