import { z } from "zod";
import { iObjectMetaSchema } from "@soft-stech/apimachinery/apis/meta/v1/ObjectMeta.schema";
/**
 * Shovel is the Schema for the shovels API
 */
export const IShovelSchema = z.object({
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    "apiVersion": z.literal("rabbitmq.com/v1beta1"),
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    "kind": z.literal("Shovel"),
    "metadata": iObjectMetaSchema.optional(),
    /**
     * ShovelSpec defines the desired state of Shovel For how to configure Shovel, see: https://www.rabbitmq.com/shovel.html.
     */
    "spec": z.object({
        "ackMode": z.union([z.literal("on-confirm"), z.literal("on-publish"), z.literal("no-ack")]).optional(),
        "addForwardHeaders": z.boolean().optional(),
        "deleteAfter": z.string().optional(),
        "destAddForwardHeaders": z.boolean().optional(),
        "destAddTimestampHeader": z.boolean().optional(),
        "destAddress": z.string().optional(),
        "destApplicationProperties": z.string().optional(),
        "destExchange": z.string().optional(),
        "destExchangeKey": z.string().optional(),
        "destProperties": z.string().optional(),
        "destProtocol": z.string().optional(),
        "destPublishProperties": z.string().optional(),
        "destQueue": z.string().optional(),
        /**
         * Required property; cannot be updated
         */
        "name": z.string(),
        "prefetchCount": z.number().optional(),
        /**
         * Reference to the RabbitmqCluster that this Shovel will be created in. Required property.
         */
        "rabbitmqClusterReference": z.object({
            /**
             * Secret contains the http management uri for the RabbitMQ cluster. The Secret must contain the key `uri`, `username` and `password` or operator will error. Have to set either name or connectionSecret, but not both.
             */
            "connectionSecret": z.object({
                /**
                 * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                 */
                "name": z.string().optional()
            }).optional(),
            /**
             * The name of the RabbitMQ cluster to reference. Have to set either name or connectionSecret, but not both.
             */
            "name": z.string().optional(),
            /**
             * The namespace of the RabbitMQ cluster to reference. Defaults to the namespace of the requested resource if omitted.
             */
            "namespace": z.string().optional()
        }),
        "reconnectDelay": z.number().optional(),
        "srcAddress": z.string().optional(),
        "srcDeleteAfter": z.string().optional(),
        "srcExchange": z.string().optional(),
        "srcExchangeKey": z.string().optional(),
        "srcPrefetchCount": z.number().optional(),
        "srcProtocol": z.string().optional(),
        "srcQueue": z.string().optional(),
        /**
         * Secret contains the AMQP URI(s) to configure Shovel destination and source. The Secret must contain the key `destUri` and `srcUri` or operator will error. Both fields should be one or multiple uris separated by ','. Required property.
         */
        "uriSecret": z.object({
            /**
             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
             */
            "name": z.string().optional()
        }),
        /**
         * Default to vhost '/'; cannot be updated
         * @default "/"
         */
        "vhost": z.string().optional().default("/")
    }).optional(),
    /**
     * ShovelStatus defines the observed state of Shovel
     */
    "status": z.object({
        "conditions": z.array(z.object({
            /**
             * The last time this Condition status changed.
             * @format date-time
             */
            "lastTransitionTime": z.string().datetime().optional().nullable(),
            /**
             * Full text reason for current status of the condition.
             */
            "message": z.string().optional(),
            /**
             * One word, camel-case reason for current status of the condition.
             */
            "reason": z.string().optional(),
            /**
             * True, False, or Unknown
             */
            "status": z.string(),
            /**
             * Type indicates the scope of the custom resource status addressed by the condition.
             */
            "type": z.string()
        })).optional(),
        /**
         * observedGeneration is the most recent successful generation observed for this Shovel. It corresponds to the Shovel's generation, which is updated on mutation by the API Server.
         * @format int64
         */
        "observedGeneration": z.number().optional()
    }).optional()
});
