import { z } from "zod";
/**
 * User is the Schema for the users API.
 */
export declare const IUserSchema: z.ZodObject<{
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    apiVersion: z.ZodLiteral<"rabbitmq.com/v1beta1">;
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    kind: z.ZodLiteral<"User">;
    metadata: z.ZodOptional<z.ZodObject<{
        annotations: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        creationTimestamp: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        deletionGracePeriodSeconds: z.ZodOptional<z.ZodNumber>;
        deletionTimestamp: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        finalizers: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        generateName: z.ZodOptional<z.ZodString>;
        generation: z.ZodOptional<z.ZodNumber>;
        labels: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
        managedFields: z.ZodOptional<z.ZodArray<z.ZodObject<{
            apiVersion: z.ZodOptional<z.ZodString>;
            fieldsType: z.ZodOptional<z.ZodString>;
            fieldsV1: z.ZodOptional<z.ZodObject<{}, "strip", z.ZodTypeAny, {}, {}>>;
            manager: z.ZodOptional<z.ZodString>;
            operation: z.ZodOptional<z.ZodString>;
            subresource: z.ZodOptional<z.ZodString>;
            time: z.ZodOptional<z.ZodNullable<z.ZodString>>;
        }, "strip", z.ZodTypeAny, {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }, {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }>, "many">>;
        name: z.ZodOptional<z.ZodString>;
        namespace: z.ZodOptional<z.ZodString>;
        ownerReferences: z.ZodOptional<z.ZodArray<z.ZodObject<{
            apiVersion: z.ZodString;
            blockOwnerDeletion: z.ZodOptional<z.ZodBoolean>;
            controller: z.ZodOptional<z.ZodBoolean>;
            kind: z.ZodString;
            name: z.ZodString;
            uid: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }, {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }>, "many">>;
        resourceVersion: z.ZodOptional<z.ZodString>;
        selfLink: z.ZodOptional<z.ZodString>;
        uid: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    }, {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    }>>;
    /**
     * Spec configures the desired state of the User object.
     */
    spec: z.ZodOptional<z.ZodObject<{
        /**
         * Defines a Secret used to pre-define the username and password set for this User. User objects created with this field set will not have randomly-generated credentials, and will instead import the username/password values from this Secret. The Secret must contain the keys `username` and `password` in its Data field, or the import will fail. Note that this import only occurs at creation time, and is ignored once a password has been set on a User.
         */
        importCredentialsSecret: z.ZodOptional<z.ZodObject<{
            /**
             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
             */
            name: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            name?: string | undefined;
        }, {
            name?: string | undefined;
        }>>;
        /**
         * Reference to the RabbitmqCluster that the user will be created for. This cluster must exist for the User object to be created.
         */
        rabbitmqClusterReference: z.ZodObject<{
            /**
             * Secret contains the http management uri for the RabbitMQ cluster. The Secret must contain the key `uri`, `username` and `password` or operator will error. Have to set either name or connectionSecret, but not both.
             */
            connectionSecret: z.ZodOptional<z.ZodObject<{
                /**
                 * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                 */
                name: z.ZodOptional<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                name?: string | undefined;
            }, {
                name?: string | undefined;
            }>>;
            /**
             * The name of the RabbitMQ cluster to reference. Have to set either name or connectionSecret, but not both.
             */
            name: z.ZodOptional<z.ZodString>;
            /**
             * The namespace of the RabbitMQ cluster to reference. Defaults to the namespace of the requested resource if omitted.
             */
            namespace: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            name?: string | undefined;
            connectionSecret?: {
                name?: string | undefined;
            } | undefined;
            namespace?: string | undefined;
        }, {
            name?: string | undefined;
            connectionSecret?: {
                name?: string | undefined;
            } | undefined;
            namespace?: string | undefined;
        }>;
        /**
         * List of permissions tags to associate with the user. This determines the level of access to the RabbitMQ management UI granted to the user. Omitting this field will lead to a user than can still connect to the cluster through messaging protocols, but cannot perform any management actions. For more information, see https://www.rabbitmq.com/management.html#permissions.
         */
        tags: z.ZodOptional<z.ZodArray<z.ZodUnion<[z.ZodLiteral<"management">, z.ZodLiteral<"policymaker">, z.ZodLiteral<"monitoring">, z.ZodLiteral<"administrator">]>, "many">>;
    }, "strip", z.ZodTypeAny, {
        rabbitmqClusterReference: {
            name?: string | undefined;
            connectionSecret?: {
                name?: string | undefined;
            } | undefined;
            namespace?: string | undefined;
        };
        importCredentialsSecret?: {
            name?: string | undefined;
        } | undefined;
        tags?: ("management" | "policymaker" | "monitoring" | "administrator")[] | undefined;
    }, {
        rabbitmqClusterReference: {
            name?: string | undefined;
            connectionSecret?: {
                name?: string | undefined;
            } | undefined;
            namespace?: string | undefined;
        };
        importCredentialsSecret?: {
            name?: string | undefined;
        } | undefined;
        tags?: ("management" | "policymaker" | "monitoring" | "administrator")[] | undefined;
    }>>;
    /**
     * Status exposes the observed state of the User object.
     */
    status: z.ZodOptional<z.ZodObject<{
        conditions: z.ZodOptional<z.ZodArray<z.ZodObject<{
            /**
             * The last time this Condition status changed.
             * @format date-time
             */
            lastTransitionTime: z.ZodNullable<z.ZodOptional<z.ZodString>>;
            /**
             * Full text reason for current status of the condition.
             */
            message: z.ZodOptional<z.ZodString>;
            /**
             * One word, camel-case reason for current status of the condition.
             */
            reason: z.ZodOptional<z.ZodString>;
            /**
             * True, False, or Unknown
             */
            status: z.ZodString;
            /**
             * Type indicates the scope of the custom resource status addressed by the condition.
             */
            type: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            type: string;
            status: string;
            message?: string | undefined;
            lastTransitionTime?: string | null | undefined;
            reason?: string | undefined;
        }, {
            type: string;
            status: string;
            message?: string | undefined;
            lastTransitionTime?: string | null | undefined;
            reason?: string | undefined;
        }>, "many">>;
        /**
         * Provides a reference to a Secret object containing the user credentials.
         */
        credentials: z.ZodOptional<z.ZodObject<{
            /**
             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
             */
            name: z.ZodOptional<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            name?: string | undefined;
        }, {
            name?: string | undefined;
        }>>;
        /**
         * observedGeneration is the most recent successful generation observed for this User. It corresponds to the User's generation, which is updated on mutation by the API Server.
         * @format int64
         */
        observedGeneration: z.ZodOptional<z.ZodNumber>;
        /**
         * Provide rabbitmq Username
         */
        username: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        username: string;
        conditions?: {
            type: string;
            status: string;
            message?: string | undefined;
            lastTransitionTime?: string | null | undefined;
            reason?: string | undefined;
        }[] | undefined;
        observedGeneration?: number | undefined;
        credentials?: {
            name?: string | undefined;
        } | undefined;
    }, {
        username: string;
        conditions?: {
            type: string;
            status: string;
            message?: string | undefined;
            lastTransitionTime?: string | null | undefined;
            reason?: string | undefined;
        }[] | undefined;
        observedGeneration?: number | undefined;
        credentials?: {
            name?: string | undefined;
        } | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    apiVersion: "rabbitmq.com/v1beta1";
    kind: "User";
    status?: {
        username: string;
        conditions?: {
            type: string;
            status: string;
            message?: string | undefined;
            lastTransitionTime?: string | null | undefined;
            reason?: string | undefined;
        }[] | undefined;
        observedGeneration?: number | undefined;
        credentials?: {
            name?: string | undefined;
        } | undefined;
    } | undefined;
    metadata?: {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    } | undefined;
    spec?: {
        rabbitmqClusterReference: {
            name?: string | undefined;
            connectionSecret?: {
                name?: string | undefined;
            } | undefined;
            namespace?: string | undefined;
        };
        importCredentialsSecret?: {
            name?: string | undefined;
        } | undefined;
        tags?: ("management" | "policymaker" | "monitoring" | "administrator")[] | undefined;
    } | undefined;
}, {
    apiVersion: "rabbitmq.com/v1beta1";
    kind: "User";
    status?: {
        username: string;
        conditions?: {
            type: string;
            status: string;
            message?: string | undefined;
            lastTransitionTime?: string | null | undefined;
            reason?: string | undefined;
        }[] | undefined;
        observedGeneration?: number | undefined;
        credentials?: {
            name?: string | undefined;
        } | undefined;
    } | undefined;
    metadata?: {
        name?: string | undefined;
        uid?: string | undefined;
        resourceVersion?: string | undefined;
        selfLink?: string | undefined;
        annotations?: Record<string, string> | undefined;
        creationTimestamp?: string | null | undefined;
        deletionGracePeriodSeconds?: number | undefined;
        deletionTimestamp?: string | null | undefined;
        finalizers?: string[] | undefined;
        generateName?: string | undefined;
        generation?: number | undefined;
        labels?: Record<string, string> | undefined;
        managedFields?: {
            apiVersion?: string | undefined;
            fieldsType?: string | undefined;
            fieldsV1?: {} | undefined;
            manager?: string | undefined;
            operation?: string | undefined;
            subresource?: string | undefined;
            time?: string | null | undefined;
        }[] | undefined;
        namespace?: string | undefined;
        ownerReferences?: {
            apiVersion: string;
            kind: string;
            name: string;
            uid: string;
            blockOwnerDeletion?: boolean | undefined;
            controller?: boolean | undefined;
        }[] | undefined;
    } | undefined;
    spec?: {
        rabbitmqClusterReference: {
            name?: string | undefined;
            connectionSecret?: {
                name?: string | undefined;
            } | undefined;
            namespace?: string | undefined;
        };
        importCredentialsSecret?: {
            name?: string | undefined;
        } | undefined;
        tags?: ("management" | "policymaker" | "monitoring" | "administrator")[] | undefined;
    } | undefined;
}>;
