"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IUserSchema = void 0;
// Generated by ts-to-zod
const zod_1 = require("zod");
const ObjectMeta_schema_1 = require("@soft-stech/apimachinery/apis/meta/v1/ObjectMeta.schema");
/**
 * User is the Schema for the users API.
 */
exports.IUserSchema = zod_1.z.object({
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    "apiVersion": zod_1.z.literal("rabbitmq.com/v1beta1"),
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    "kind": zod_1.z.literal("User"),
    "metadata": ObjectMeta_schema_1.iObjectMetaSchema.optional(),
    /**
     * Spec configures the desired state of the User object.
     */
    "spec": zod_1.z.object({
        /**
         * Defines a Secret used to pre-define the username and password set for this User. User objects created with this field set will not have randomly-generated credentials, and will instead import the username/password values from this Secret. The Secret must contain the keys `username` and `password` in its Data field, or the import will fail. Note that this import only occurs at creation time, and is ignored once a password has been set on a User.
         */
        "importCredentialsSecret": zod_1.z.object({
            /**
             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
             */
            "name": zod_1.z.string().optional()
        }).optional(),
        /**
         * Reference to the RabbitmqCluster that the user will be created for. This cluster must exist for the User object to be created.
         */
        "rabbitmqClusterReference": zod_1.z.object({
            /**
             * Secret contains the http management uri for the RabbitMQ cluster. The Secret must contain the key `uri`, `username` and `password` or operator will error. Have to set either name or connectionSecret, but not both.
             */
            "connectionSecret": zod_1.z.object({
                /**
                 * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                 */
                "name": zod_1.z.string().optional()
            }).optional(),
            /**
             * The name of the RabbitMQ cluster to reference. Have to set either name or connectionSecret, but not both.
             */
            "name": zod_1.z.string().optional(),
            /**
             * The namespace of the RabbitMQ cluster to reference. Defaults to the namespace of the requested resource if omitted.
             */
            "namespace": zod_1.z.string().optional()
        }),
        /**
         * List of permissions tags to associate with the user. This determines the level of access to the RabbitMQ management UI granted to the user. Omitting this field will lead to a user than can still connect to the cluster through messaging protocols, but cannot perform any management actions. For more information, see https://www.rabbitmq.com/management.html#permissions.
         */
        "tags": zod_1.z.array(zod_1.z.union([zod_1.z.literal("management"), zod_1.z.literal("policymaker"), zod_1.z.literal("monitoring"), zod_1.z.literal("administrator")])).optional()
    }).optional(),
    /**
     * Status exposes the observed state of the User object.
     */
    "status": zod_1.z.object({
        "conditions": zod_1.z.array(zod_1.z.object({
            /**
             * The last time this Condition status changed.
             * @format date-time
             */
            "lastTransitionTime": zod_1.z.string().datetime().optional().nullable(),
            /**
             * Full text reason for current status of the condition.
             */
            "message": zod_1.z.string().optional(),
            /**
             * One word, camel-case reason for current status of the condition.
             */
            "reason": zod_1.z.string().optional(),
            /**
             * True, False, or Unknown
             */
            "status": zod_1.z.string(),
            /**
             * Type indicates the scope of the custom resource status addressed by the condition.
             */
            "type": zod_1.z.string()
        })).optional(),
        /**
         * Provides a reference to a Secret object containing the user credentials.
         */
        "credentials": zod_1.z.object({
            /**
             * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
             */
            "name": zod_1.z.string().optional()
        }).optional(),
        /**
         * observedGeneration is the most recent successful generation observed for this User. It corresponds to the User's generation, which is updated on mutation by the API Server.
         * @format int64
         */
        "observedGeneration": zod_1.z.number().optional(),
        /**
         * Provide rabbitmq Username
         */
        "username": zod_1.z.string()
    }).optional()
});
