import { z } from "zod";
import { iObjectMetaSchema } from "@soft-stech/apimachinery/apis/meta/v1/ObjectMeta.schema";
/**
 * Vhost is the Schema for the vhosts API
 */
export const IVhostSchema = z.object({
    /**
     * APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
     */
    "apiVersion": z.literal("rabbitmq.com/v1beta1"),
    /**
     * Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
     */
    "kind": z.literal("Vhost"),
    "metadata": iObjectMetaSchema.optional(),
    /**
     * VhostSpec defines the desired state of Vhost
     */
    "spec": z.object({
        /**
         * Name of the vhost; see https://www.rabbitmq.com/vhosts.html.
         */
        "name": z.string(),
        /**
         * Reference to the RabbitmqCluster that the vhost will be created in. Required property.
         */
        "rabbitmqClusterReference": z.object({
            /**
             * Secret contains the http management uri for the RabbitMQ cluster. The Secret must contain the key `uri`, `username` and `password` or operator will error. Have to set either name or connectionSecret, but not both.
             */
            "connectionSecret": z.object({
                /**
                 * Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names TODO: Add other useful fields. apiVersion, kind, uid?
                 */
                "name": z.string().optional()
            }).optional(),
            /**
             * The name of the RabbitMQ cluster to reference. Have to set either name or connectionSecret, but not both.
             */
            "name": z.string().optional(),
            /**
             * The namespace of the RabbitMQ cluster to reference. Defaults to the namespace of the requested resource if omitted.
             */
            "namespace": z.string().optional()
        }),
        "tags": z.array(z.string()).optional(),
        "tracing": z.boolean().optional()
    }).optional(),
    /**
     * VhostStatus defines the observed state of Vhost
     */
    "status": z.object({
        "conditions": z.array(z.object({
            /**
             * The last time this Condition status changed.
             * @format date-time
             */
            "lastTransitionTime": z.string().datetime().optional().nullable(),
            /**
             * Full text reason for current status of the condition.
             */
            "message": z.string().optional(),
            /**
             * One word, camel-case reason for current status of the condition.
             */
            "reason": z.string().optional(),
            /**
             * True, False, or Unknown
             */
            "status": z.string(),
            /**
             * Type indicates the scope of the custom resource status addressed by the condition.
             */
            "type": z.string()
        })).optional(),
        /**
         * observedGeneration is the most recent successful generation observed for this Vhost. It corresponds to the Vhost's generation, which is updated on mutation by the API Server.
         * @format int64
         */
        "observedGeneration": z.number().optional()
    }).optional()
});
